@@ -21,11 +21,9 @@ OS = __get_operating_system__()
 # universal variables.
 OWNER = os.environ.get("USER")
 GROUP = "root"
-HOME_BASE = "/home/"
-HOME = f"/home/{os.environ.get('USER')}/"
+HOME = os.environ.get('HOME')
+HOME_BASE = gfp.base(path=HOME)
 MEDIA = f"/media/{os.environ.get('USER')}/"
 if OS in ["macos"]: 
-	HOME_BASE = "/Users/"
-	HOME = f"/Users/{os.environ.get('USER')}/"
 	MEDIA = f"/Volumes/"
 	GROUP = "wheel"
