@@ -2,6 +2,10 @@
 # -*- coding: utf-8 -*-
 
 # exceptions.
+class InvalidFormatError(Exception):
+	pass
+class ArgumentFormatError(Exception):
+	pass
 class EmptyArgumentError(Exception):
 	pass
 class ArgumentError(Exception):
